@@ -2,10 +2,6 @@
 #define _CHUNK_H_
 #include "first.h"
 
-#ifdef _AIX  /*(AIX might #define mmap mmap64)*/
-#include "sys-mmap.h"
-#endif
-
 #include "buffer.h"
 #include "array.h"
 #include "fdlog.h"
@@ -14,6 +10,13 @@
 #define MAX_READ_LIMIT  (256*1024)
 #define MAX_WRITE_LIMIT (256*1024)
 
+typedef struct chunk_file_view {
+	char    *mptr; /* base pointer of mmap'ed area */
+	off_t    mlen; /* length of mmap'ed area */
+	off_t    foff; /* offset from the start of the file */
+	int    refcnt;
+} chunk_file_view;
+
 typedef struct chunk {
 	struct chunk *next;
 	enum { MEM_CHUNK, FILE_CHUNK } type;
@@ -31,12 +34,12 @@ typedef struct chunk {
 		off_t  length; /* end pos + 1 in file (octets to send: file.length - c->offset) */
 
 		int    fd;
-		int is_temp; /* file is temporary and will be deleted if on cleanup */
-		struct {
-			char   *start; /* the start pointer of the mmap'ed area */
-			size_t length; /* size of the mmap'ed area */
-			off_t  offset; /* start is <n> octet away from the start of the file */
-		} mmap;
+		uint8_t is_temp; /* file is temporary and will be deleted if on cleanup */
+		uint8_t busy;    /* file chunk not in page cache; reading might block */
+		uint8_t flagmask;/* (internal; used with preadv2() RWF_NOWAIT) */
+	  #if defined(HAVE_MMAP) || defined(_WIN32) /*(see local sys-mmap.h)*/
+		chunk_file_view *view;
+	  #endif
 		void *ref;
 		void(*refchg)(void *, int);
 	} file;
@@ -48,11 +51,15 @@ typedef struct chunkqueue {
 
 	off_t bytes_in, bytes_out;
 
-	const array *tempdirs;
 	off_t upload_temp_file_size;
 	unsigned int tempdir_idx;
 } chunkqueue;
 
+ssize_t chunk_file_pread (int fd, void *buf, size_t count, off_t offset);
+
+/* attempts non-blocking preadv2 RWF_NOWAIT on Linux, else chunk_file_pread() */
+ssize_t chunk_file_pread_chunk (chunk *c, void *buf, size_t count);
+
 __attribute_returns_nonnull__
 buffer * chunk_buffer_acquire(void);
 
@@ -78,7 +85,10 @@ void chunkqueue_set_tempdirs_default_reset (void);
 __attribute_cold__
 void chunkqueue_set_tempdirs_default (const array *tempdirs, off_t upload_temp_file_size);
 
-void chunkqueue_set_tempdirs(chunkqueue * restrict cq, const array * restrict tempdirs, off_t upload_temp_file_size);
+void chunkqueue_set_tempdirs(chunkqueue * restrict cq, off_t upload_temp_file_size);
+
+__attribute_cold__
+const char *chunkqueue_env_tmpdir(void);
 
 void chunkqueue_append_file(chunkqueue * restrict cq, const buffer * restrict fn, off_t offset, off_t len); /* copies "fn" */
 void chunkqueue_append_file_fd(chunkqueue * restrict cq, const buffer * restrict fn, int fd, off_t offset, off_t len); /* copies "fn" */
@@ -146,7 +156,7 @@ void chunkqueue_steal(chunkqueue * restrict dest, chunkqueue * restrict src, off
 int chunkqueue_steal_with_tempfiles(chunkqueue * restrict dest, chunkqueue * restrict src, off_t len, log_error_st * const restrict errh);
 void chunkqueue_append_cq_range (chunkqueue *dst, const chunkqueue *src, off_t offset, off_t len);
 
-int chunkqueue_open_file_chunk(chunkqueue * restrict cq, log_error_st * const restrict errh);
+int chunk_open_file_chunk(chunk * restrict c, log_error_st * restrict errh);
 
 void chunkqueue_compact_mem_offset(chunkqueue *cq);
 void chunkqueue_compact_mem(chunkqueue *cq, size_t clen);
@@ -156,12 +166,13 @@ void chunkqueue_small_resp_optim (chunkqueue * restrict cq);
 ssize_t chunkqueue_write_chunk (int fd, chunkqueue * restrict cq, log_error_st * restrict errh);
 ssize_t chunkqueue_write_chunk_to_pipe (int fd, chunkqueue * restrict cq, log_error_st * restrict errh);
 
-int chunkqueue_peek_data (chunkqueue *cq, char **data, uint32_t *dlen, log_error_st * restrict errh);
+int chunkqueue_peek_data (chunkqueue *cq, char **data, uint32_t *dlen, log_error_st * restrict errh, int nowait);
 int chunkqueue_read_data (chunkqueue *cq, char *data, uint32_t dlen, log_error_st * restrict errh);
 
-buffer * chunkqueue_read_squash (chunkqueue * restrict cq, log_error_st * restrict errh);
+chunk * chunkqueue_read_squash (chunkqueue * restrict cq, log_error_st * restrict errh);
 
 __attribute_pure__
+__attribute_nonnull__()
 static inline off_t chunkqueue_length(const chunkqueue *cq);
 static inline off_t chunkqueue_length(const chunkqueue *cq) {
 	return cq->bytes_in - cq->bytes_out;
@@ -173,9 +184,55 @@ void chunkqueue_free(chunkqueue *cq);
 void chunkqueue_reset(chunkqueue *cq);
 
 __attribute_pure__
+__attribute_nonnull__()
 static inline int chunkqueue_is_empty(const chunkqueue *cq);
 static inline int chunkqueue_is_empty(const chunkqueue *cq) {
 	return NULL == cq->first;
 }
 
+const chunk_file_view * chunkqueue_chunk_file_viewadj (chunk *c, off_t n, log_error_st * restrict errh);
+
+__attribute_pure__
+__attribute_nonnull__()
+static inline char *
+chunk_file_view_dptr (const chunk_file_view * const cfv, off_t offset);
+static inline char *
+chunk_file_view_dptr (const chunk_file_view * const cfv, off_t offset)
+{
+    return cfv->mptr - cfv->foff + offset;
+}
+
+__attribute_pure__
+__attribute_nonnull__()
+static inline off_t
+chunk_file_view_dlen (const chunk_file_view * const cfv, off_t offset);
+static inline off_t
+chunk_file_view_dlen (const chunk_file_view * const cfv, off_t offset)
+{
+    return cfv->mlen + cfv->foff - offset;
+}
+
+static inline const chunk_file_view *
+chunkqueue_chunk_file_view (chunk * const c, const off_t n, log_error_st * const restrict errh);
+static inline const chunk_file_view *
+chunkqueue_chunk_file_view (chunk * const c, const off_t n, log_error_st * const restrict errh)
+{
+    /*assert(c->type == FILE_CHUNK);*/
+  #if defined(HAVE_MMAP) || defined(_WIN32) /*(see local sys-mmap.h)*/
+    /* mmap buffer if offset is outside old mmap area or not mapped at all */
+    const chunk_file_view * const restrict cfv = c->file.view;
+    if (NULL == cfv
+        ? c->file.length - c->offset >= 131072 /* TBD: min chunk size to mmap */
+        : (c->offset - cfv->foff < 0
+           || chunk_file_view_dlen(cfv, c->offset) < (n ? n : 1)))
+        return chunkqueue_chunk_file_viewadj(c, n, errh);
+    return cfv;
+  #else
+    UNUSED(c);
+    UNUSED(n);
+    UNUSED(errh);
+    return NULL;
+  #endif
+}
+
 #endif
