@@ -18,12 +18,15 @@
 #endif
 #endif
 #include "first.h"
-#if defined(__FreeBSD__) || defined(__sun)
+#if defined(__FreeBSD__) || defined(__DragonFly__) || defined(__sun)
 #ifndef _RSIZE_T_DEFINED /* expecting __EXT1_VISIBLE 1 and _RSIZE_T_DEFINED */
 #define _RSIZE_T_DEFINED
 typedef size_t rsize_t;
 #endif
 #include <errno.h>
+#if defined(__DragonFly__)
+typedef int errno_t;
+#endif
 #endif
 
 __BEGIN_DECLS
@@ -115,4 +118,11 @@ void ck_assert_failed(const char *filename, unsigned int line, const char *msg);
 __END_DECLS
 
 
+#include <assert.h>     /* C11 static_assert() and _Static_assert() */
+#ifndef static_assert
+#define static_assert(x,str) ck_assert(x)
+#endif
+#define ck_static_assert(x) static_assert((x),#x)
+
+
 #endif
