@@ -459,6 +459,8 @@ SETDEFAULTS_FUNC(mod_accesslog_set_defaults) {
     p->defaults.syslog_level = LOG_INFO;
     if (uses_syslog)
         fdlog_openlog(srv->errh, srv->srvconf.syslog_facility);
+  #else
+    UNUSED(uses_syslog);
   #endif
 
     /* initialize p->defaults from global config context */
@@ -575,7 +577,8 @@ static format_fields * mod_accesslog_process_format(const char * const format, c
 					}
 				} else if (FORMAT_HEADER == f->field
 				           || FORMAT_RESPONSE_HEADER == f->field) {
-					f->opt = http_header_hkey_get(BUF_PTR_LEN(fstr));
+					if (buffer_is_blank(fstr)) f->field = FORMAT_LITERAL; /*(blank)*/
+					else f->opt = http_header_hkey_get(BUF_PTR_LEN(fstr));
 				} else if (FORMAT_REMOTE_HOST == f->field
 				           || FORMAT_REMOTE_ADDR == f->field) {
 					f->field = FORMAT_REMOTE_ADDR;
@@ -593,8 +596,10 @@ static format_fields * mod_accesslog_process_format(const char * const format, c
 				} else if (FORMAT_REMOTE_USER == f->field) {
 					f->field = FORMAT_ENV;
 					buffer_copy_string_len(fstr, CONST_STR_LEN("REMOTE_USER"));
-				} else if (FORMAT_NOTE == f->field) {
-					f->field = FORMAT_ENV;
+				} else if (FORMAT_ENV == f->field
+				           || FORMAT_NOTE == f->field) {
+					if (buffer_is_blank(fstr)) f->field = FORMAT_LITERAL; /*(blank)*/
+					else f->field = FORMAT_ENV;
 				}
 			}
 
