@@ -16,6 +16,12 @@
 
 #include "sys-socket.h"
 
+#ifndef _WIN32
+#include <arpa/inet.h>  /* ntohs() */
+#else
+#include <winsock2.h>   /* ntohs() */
+#endif
+
 /**
  * mod_extforward.c for lighttpd, by comman.kang <at> gmail <dot> com
  *                  extended, modified by Lionel Elie Mamane (LEM), lionel <at> mamane <dot> lu
@@ -313,7 +319,7 @@ static unsigned int mod_extforward_parse_opts(server *srv, const array *opts_par
             return UINT_MAX;
         }
 
-        int val = config_plugin_value_tobool(du, 2);
+        int val = config_plugin_value_to_bool(du, 2);
         if (2 == val) {
             log_error(srv->errh, __FILE__, __LINE__,
               "extforward.params values must be one of: "
