@@ -74,7 +74,7 @@ vhostdb_cache_free (vhostdb_cache *vc)
     splay_tree *sptree = vc->sptree;
     while (sptree) {
         vhostdb_cache_entry_free(sptree->data);
-        sptree = splaytree_delete(sptree, sptree->key);
+        sptree = splaytree_delete_splayed_node(sptree);
     }
     free(vc);
 }
@@ -118,7 +118,7 @@ mod_vhostdb_cache_insert (request_st * const r, plugin_data * const p, vhostdb_c
      * and splaytree has not been modified since mod_vhostdb_cache_query())*/
     /* *sptree = splaytree_splay(*sptree, ndx); */
     if (NULL == *sptree || (*sptree)->key != ndx)
-        *sptree = splaytree_insert(*sptree, ndx, ve);
+        *sptree = splaytree_insert_splayed(*sptree, ndx, ve);
     else { /* collision; replace old entry */
         vhostdb_cache_entry_free((*sptree)->data);
         (*sptree)->data = ve;
@@ -344,12 +344,9 @@ mod_vhostdb_periodic_cleanup(splay_tree **sptree_ptr, const time_t max_age, cons
         max_ndx = 0;
         mod_vhostdb_tag_old_entries(sptree, keys, &max_ndx, max_age, cur_ts);
         for (i = 0; i < max_ndx; ++i) {
-            int ndx = keys[i];
-            sptree = splaytree_splay(sptree, ndx);
-            if (sptree && sptree->key == ndx) {
-                vhostdb_cache_entry_free(sptree->data);
-                sptree = splaytree_delete(sptree, ndx);
-            }
+            sptree = splaytree_splay_nonnull(sptree, keys[i]);
+            vhostdb_cache_entry_free(sptree->data);
+            sptree = splaytree_delete_splayed_node(sptree);
         }
     } while (max_ndx == sizeof(keys)/sizeof(int));
     *sptree_ptr = sptree;
@@ -381,6 +378,7 @@ TRIGGER_FUNC(mod_vhostdb_periodic)
 
 
 __attribute_cold__
+__declspec_dllexport__
 int mod_vhostdb_plugin_init(plugin *p);
 int mod_vhostdb_plugin_init(plugin *p) {
     p->version          = LIGHTTPD_VERSION_ID;
