@@ -61,14 +61,20 @@ static void test_keyvalue_pcre_keyvalue_buffer_process (void) {
     buffer_copy_string_len(scheme, CONST_STR_LEN("http"));
     buffer_copy_string_len(authority, CONST_STR_LEN("www.example.com"));
     /* model outer conditional match of $HTTP["host"] =~ "^(www).example.com$" */
-    ctx.cond_match_count = 2;
     ctx.cache = &cache;
     memset(&cache, 0, sizeof(cache));
     cache.comp_value = authority;
-    cache.matches[0] = 0;
-    cache.matches[1] = 15;
-    cache.matches[2] = 0;
-    cache.matches[3] = 3;
+    cache.captures = 2;
+  #ifdef HAVE_PCRE2_H
+    PCRE2_SIZE matches[4];
+  #else /* HAVE_PCRE_H */
+    int matches[4];
+  #endif
+    matches[0] = 0;
+    matches[1] = 15;
+    matches[2] = 0;
+    matches[3] = 3;
+    cache.matches = matches;
 
     /* converted from prior sparse tests/mod-redirect.t and tests/mod-rewrite.t
      * (real-world use should prefer ${url.path} and ${qsa} in substitutions)
@@ -119,9 +125,10 @@ static void test_keyvalue_pcre_keyvalue_buffer_process (void) {
 }
 #endif
 
-int main (void) {
+void test_keyvalue (void);
+void test_keyvalue (void)
+{
   #ifdef HAVE_PCRE_H
     test_keyvalue_pcre_keyvalue_buffer_process();
   #endif
-    return 0;
 }
